AddAuthorization extension
- on
-
- Request
Methods
-
setAuthorization(
DescopeSessionManager sessionManager) → void -
Available on Request, provided by the AddAuthorization extension
Ensures that the active session in a DescopeSessionManager is valid and then sets its session JWT as the Bearer Token value of the Authorization header field in thehttp.Request. -
setAuthorizationFromSession(
DescopeSession session) → void -
Available on Request, provided by the AddAuthorization extension
Sets the session JWT from a DescopeSession as the Bearer Token value of the Authorization header field in thehttp.Request. -
setAuthorizationFromToken(
DescopeToken token) → void -
Available on Request, provided by the AddAuthorization extension
Sets the JWT from a DescopeToken as the Bearer Token value of the Authorization header field in thehttp.Request.