signUp abstract method
Future<EnchantedLinkResponse>
signUp({
- required String loginId,
- SignUpDetails? details,
- String? redirectUrl,
Authenticates a new user using an enchanted link, sent via email.
A new user identified by loginId and the optional details details will be added
upon successful authentication.
The caller should use the returned EnchantedLinkResponse.linkId to show the
user which link they need to press in the enchanted link email, and then use
the EnchantedLinkResponse.pendingRef value to poll until the authentication is verified.
Important: Make sure an email address is provided via
the details parameter or as the loginId itself.
Important: Make sure a default enchanted link URL is configured
in the Descope console, or provided via redirectUrl by this call.
Implementation
Future<EnchantedLinkResponse> signUp({required String loginId, SignUpDetails? details, String? redirectUrl});