clientInputs property

Map<String, dynamic>? clientInputs
getter/setter pair

An optional map of client inputs that will be provided to the flow.

These values can be used in the flow editor to customize the flow's behavior during execution. The values must be valid JSON types.

Implementation

Map<String, dynamic>? clientInputs;