unsafe property

bool unsafe
getter/setter pair

Whether to print unsafe runtime values.

When set to true, log output will include potentially sensitive runtime values such as personal information, network payloads, etc. This should not be enabled in release builds intended for production.

Implementation

bool unsafe;