DescopeMobileFlowOptions class

Options to run a mobile flow

Provide a flowUrl where the flow is hosted. When targeting Android, or when the flow contains a magic link, make sure to provide a deepLinkUrl to resume or complete the flow using the exchange function.

Constructors

DescopeMobileFlowOptions({required String flowUrl, String? deepLinkUrl})

Properties

deepLinkUrl ↔ String?
getter/setter pair
flowUrl ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited