exchange abstract method
Completes an OAuth redirect chain.
This function exchanges the code received in the code URL
parameter for an AuthenticationResponse.
Implementation
Future<AuthenticationResponse> exchange({required String code});
Completes an OAuth redirect chain.
This function exchanges the code received in the code URL
parameter for an AuthenticationResponse.
Future<AuthenticationResponse> exchange({required String code});