DescopeSessionLifecycle class abstract
This abstract class can be used to customize how a DescopeSessionManager object
manages its DescopeSession while the application is running.
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- onRefresh ↔ void Function()?
-
Called by the SessionLifecycle after a periodic session refresh succeeds.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- session ↔ DescopeSession?
-
Set by the session manager whenever the current active session changes.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
refreshSessionIfNeeded(
) → Future< void> - Called by the session manager to conditionally refresh the active session.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited