refreshSessionIfNeeded abstract method
Called by the session manager to conditionally refresh the active session.
Implementation
Future<void> refreshSessionIfNeeded();
Called by the session manager to conditionally refresh the active session.
Future<void> refreshSessionIfNeeded();