SessionLifecycle class

The default implementation of the DescopeSessionLifecycle interface.

The SessionLifecycle class periodically checks if the session needs to be refreshed (every 30 seconds by default). The refreshSessionIfNeeded function will refresh the session if it's about to expire (within 60 seconds by default) or if it's already expired.

The periodic check is paused when the application is moved to the background and resumed when it returns to the foreground.

Implemented types
Mixed-in types

Constructors

SessionLifecycle(DescopeAuth _auth, [DescopeLogger? _logger])

Properties

hashCode int
The hash code for this object.
no setterinherited
onRefresh ↔ void Function()?
Called by the SessionLifecycle after a periodic session refresh succeeds.
getter/setter pairoverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
session DescopeSession?
Set by the session manager whenever the current active session changes.
getter/setter pairoverride
stalenessAllowedInterval Duration
getter/setter pair
stalenessCheckFrequency Duration
getter/setter pair

Methods

didChangeAccessibilityFeatures() → void
Called when the system changes the set of currently active accessibility features.
inherited
didChangeAppLifecycleState(AppLifecycleState state) → void
Called when the system puts the app in the background or returns the app to the foreground.
override
didChangeLocales(List<Locale>? locales) → void
Called when the system tells the app that the user's locale has changed. For example, if the user changes the system language settings.
inherited
didChangeMetrics() → void
Called when the application's dimensions change. For example, when a phone is rotated.
inherited
didChangePlatformBrightness() → void
Called when the platform brightness changes.
inherited
didChangeTextScaleFactor() → void
Called when the platform's text scale factor changes.
inherited
didChangeViewFocus(ViewFocusEvent event) → void
Called whenever the PlatformDispatcher receives a notification that the focus state on a view has changed.
inherited
didHaveMemoryPressure() → void
Called when the system is running low on memory.
inherited
didPopRoute() Future<bool>
Called when the system tells the app to pop the current route, such as after a system back button press or back gesture.
inherited
didPushRoute(String route) Future<bool>
Called when the host tells the application to push a new route onto the navigator.
inherited
didPushRouteInformation(RouteInformation routeInformation) Future<bool>
Called when the host tells the application to push a new RouteInformation and a restoration state onto the router.
inherited
didRequestAppExit() Future<AppExitResponse>
Called when a request is received from the system to exit the application.
inherited
handleCancelBackGesture() → void
Called when a predictive back gesture is canceled, indicating that no navigation should occur.
inherited
handleCommitBackGesture() → void
Called when a predictive back gesture is finished successfully, indicating that the current route should be popped.
inherited
handleStartBackGesture(PredictiveBackEvent backEvent) bool
Called at the start of a predictive back gesture.
inherited
handleStatusBarTap() → void
Called when the user taps the status bar on iOS, to scroll a scroll view to the top.
inherited
handleUpdateBackGestureProgress(PredictiveBackEvent backEvent) → void
Called when a predictive back gesture moves.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refreshSessionIfNeeded() Future<void>
Called by the session manager to conditionally refresh the active session.
override
shouldRefresh(DescopeSession session) bool
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited