onRefresh property
Called by the SessionLifecycle after a periodic session refresh succeeds.
The session manager sets this to persist the updated session to storage.
Implementation
@override
void Function()? onRefresh;
Called by the SessionLifecycle after a periodic session refresh succeeds.
The session manager sets this to persist the updated session to storage.
@override
void Function()? onRefresh;