session property
Set by the session manager whenever the current active session changes.
Implementation
@override
DescopeSession? get session => _session;
Set by the session manager whenever the current active session changes.
Implementation
@override
set session(DescopeSession? session) {
if (session == _session) return;
_session = session;
if (session != null && session.refreshToken.isExpired) {
_logger?.log(level: DescopeLogger.info, message: 'Session has an expired refresh token', values: [session.refreshToken.expiresAt]);
}
_resetTimer();
}