DescopeSessionManager constructor
DescopeSessionManager(
- DescopeSessionStorage storage,
- DescopeSessionLifecycle lifecycle
Creates a new DescopeSessionManager object.
This initializer can be used to create a DescopeSessionManager instance with behaviors that are different from the defaults. You can either extend or customize the SessionStorage and SessionLifecycle classes, or supply your own implementation of the respective abstract classes.
Implementation
DescopeSessionManager(this.storage, this.lifecycle) {
lifecycle.onRefresh = _onLifecycleRefresh;
}