DescopeSessionManagerListener class abstract
A set of listener methods for events about the session managed by a DescopeSessionManager.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onUpdateTokens(
DescopeSession session) → void - Called after the session tokens are updated due to a successful refresh or by a call to DescopeSessionManager.updateTokens.
-
onUpdateUser(
DescopeSession session) → void - Called after the session is updated via DescopeSessionManager.updateUser
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited